==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/ProgramControlType.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "controlTypeGroupId", 
    "displayName"})
@JsonInclude(Include.NON_NULL)
public class ProgramControlType extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.programControlType";
    }

    @JsonProperty("controlTypeGroupId")
    protected String controlTypeGroupId;

    @JsonProperty("displayName")
    protected String displayName;

    protected ProgramControlType() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderProgramControlType() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private String controlTypeGroupId;
        private String displayName;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder controlTypeGroupId(String controlTypeGroupId) {
            this.controlTypeGroupId = controlTypeGroupId;
            this.changedFields = changedFields.add("controlTypeGroupId");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public ProgramControlType build() {
            ProgramControlType _x = new ProgramControlType();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.programControlType";
            _x.id = id;
            _x.controlTypeGroupId = controlTypeGroupId;
            _x.displayName = displayName;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="controlTypeGroupId")
    @JsonIgnore
    public Optional<String> getControlTypeGroupId() {
        return Optional.ofNullable(controlTypeGroupId);
    }

    public ProgramControlType withControlTypeGroupId(String controlTypeGroupId) {
        ProgramControlType _x = _copy();
        _x.changedFields = changedFields.add("controlTypeGroupId");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.programControlType");
        _x.controlTypeGroupId = controlTypeGroupId;
        return _x;
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ProgramControlType withDisplayName(String displayName) {
        ProgramControlType _x = _copy();
        _x.changedFields = changedFields.add("displayName");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.programControlType");
        _x.displayName = displayName;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ProgramControlType patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        ProgramControlType _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ProgramControlType put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        ProgramControlType _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private ProgramControlType _copy() {
        ProgramControlType _x = new ProgramControlType();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.controlTypeGroupId = controlTypeGroupId;
        _x.displayName = displayName;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ProgramControlType[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("controlTypeGroupId=");
        b.append(this.controlTypeGroupId);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/ProgramControlType.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "controlTypeGroupId", 
    "displayName"})
@JsonInclude(Include.NON_NULL)
public class ProgramControlType extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.programControlType";
    }

    @JsonProperty("controlTypeGroupId")
    protected String controlTypeGroupId;

    @JsonProperty("displayName")
    protected String displayName;

    protected ProgramControlType() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderProgramControlType() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private String controlTypeGroupId;
        private String displayName;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder controlTypeGroupId(String controlTypeGroupId) {
            this.controlTypeGroupId = controlTypeGroupId;
            this.changedFields = changedFields.add("controlTypeGroupId");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public ProgramControlType build() {
            ProgramControlType _x = new ProgramControlType();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.programControlType";
            _x.id = id;
            _x.controlTypeGroupId = controlTypeGroupId;
            _x.displayName = displayName;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="controlTypeGroupId")
    @JsonIgnore
    public Optional<String> getControlTypeGroupId() {
        return Optional.ofNullable(controlTypeGroupId);
    }

    public ProgramControlType withControlTypeGroupId(String controlTypeGroupId) {
        ProgramControlType _x = _copy();
        _x.changedFields = changedFields.add("controlTypeGroupId");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.programControlType");
        _x.controlTypeGroupId = controlTypeGroupId;
        return _x;
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ProgramControlType withDisplayName(String displayName) {
        ProgramControlType _x = _copy();
        _x.changedFields = changedFields.add("displayName");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.programControlType");
        _x.displayName = displayName;
        return _x;
    }

    public ProgramControlType withUnmappedField(String name, Object value) {
        ProgramControlType _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ProgramControlType patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        ProgramControlType _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ProgramControlType put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        ProgramControlType _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private ProgramControlType _copy() {
        ProgramControlType _x = new ProgramControlType();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.controlTypeGroupId = controlTypeGroupId;
        _x.displayName = displayName;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ProgramControlType[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("controlTypeGroupId=");
        b.append(this.controlTypeGroupId);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
